{% extends "base.html" %}
{% block content %}

<div class="page-header">
  <div>
    <div class="page-title">// <span>{{ module_slug }}</span></div>
  </div>
</div>

<div style="padding:2rem;">
  <div class="coming-soon">
    <div style="font-size:2rem;margin-bottom:1rem;">{{ module_icon }}</div>
    <div style="font-family:'JetBrains Mono',monospace;font-size:0.65rem;color:var(--accent);letter-spacing:0.12em;text-transform:uppercase;margin-bottom:0.5rem;">{{ module_week }}</div>
    <div style="font-family:'Bricolage Grotesque',sans-serif;font-size:1.3rem;font-weight:700;color:var(--text-primary);margin-bottom:0.5rem;">{{ module_name }}</div>
    <div style="font-size:0.85rem;color:var(--text-muted);line-height:1.75;margin-bottom:1.75rem;font-family:'DM Sans',sans-serif;">{{ module_desc }}</div>

    <!-- CLI equivalent -->
    <div style="background:var(--bg);border:1px solid var(--border);border-radius:6px;padding:0.85rem 1.1rem;text-align:left;">
      <div style="font-family:'JetBrains Mono',monospace;font-size:0.58rem;color:var(--text-faint);margin-bottom:0.45rem;">// available now via CLI</div>
      <div style="font-family:'JetBrains Mono',monospace;font-size:0.75rem;color:var(--text-dim);">$ <span style="color:var(--accent);">{{ cli_command }}</span></div>
    </div>
  </div>
</div>

{% endblock %}
